<?php

namespace Lc\ShopBundle\Form\Backend\Common;

use Doctrine\ORM\EntityManagerInterface;

use Doctrine\ORM\EntityRepository;
use Lc\ShopBundle\Context\MerchantUtilsInterface;
use Lc\ShopBundle\Context\ProductInterface;
use Symfony\Bridge\Doctrine\Form\Type\EntityType;
use Symfony\Component\Form\AbstractType;
use Symfony\Component\Form\FormBuilderInterface;
use Symfony\Component\Form\FormEvent;
use Symfony\Component\Form\FormEvents;
use Symfony\Component\OptionsResolver\OptionsResolver;

class ProductType extends AbstractType
{
        protected $em;
        protected $merchantUtils;

        public function __construct(EntityManagerInterface $entityManager, MerchantUtilsInterface $merchantUtils)
        {
                $this->em = $entityManager;
                $this->merchantUtils = $merchantUtils;
        }

        public function buildForm(FormBuilderInterface $builder, array $options)
        {
                $productClass = $this->em->getClassMetadata(ProductInterface::class);
                $currentMerchant = $this->merchantUtils->getMerchantUser();

                $builder->addEventListener(FormEvents::PRE_SET_DATA, function (FormEvent $event) use ($productClass, $options, $currentMerchant) {
                        $builder = $event->getForm()->getParent();

                        $builder->add('product', EntityType::class, array_merge($options,[
                                'class' => $productClass->name,
                                'query_builder' => function (EntityRepository $er) use ($currentMerchant) {
                                        return $er->createQueryBuilder('p')
                                                ->join('p.productFamily', 'pFamily')
                                                ->where('pFamily.merchant = :currentMerchant')
                                                ->andWhere('pFamily.status = 1')
                                                ->setParameter('currentMerchant', $currentMerchant);
                                },
                                'choice_label' => function ($product) {
                                        return $product->getProductFamily()->getTitle() . ' - ' . $product->getTitle();
                                }
                        ]));
                });
        }

        public function configureOptions(OptionsResolver $resolver)
        {
                $resolver->setDefaults([
                        'translation_domain' => 'lcshop',
                ]);
        }
}
